@@ -215,7 +215,7 @@ struct ViewMainPagePrivate
         mAdapterContainer = new QWidget;
 
         QVBoxLayout* layout = new QVBoxLayout(mAdapterContainer);
-        layout->setMargin(0);
+        layout->setContentsMargins(0, 0, 0, 0);
         layout->setSpacing(0);
         mDocumentViewContainer = new DocumentViewContainer;
         mDocumentViewContainer->setAutoFillBackground(true);
@@ -285,6 +285,8 @@ struct ViewMainPagePrivate
     void setupToolContainer()
     {
         mToolContainer = new SlideContainer;
+        mToolContainer->setAutoFillBackground(true);
+        mToolContainer->setBackgroundRole(QPalette::Mid);
     }
 
     void setupStatusBar()
@@ -304,7 +306,7 @@ struct ViewMainPagePrivate
         mDocumentCountLabel->setContentsMargins(labelMargins);
 
         QHBoxLayout* layout = new QHBoxLayout(mStatusBarContainer);
-        layout->setMargin(0);
+        layout->setContentsMargins(0, 0, 0, 0);
         layout->setSpacing(0);
         layout->addWidget(mToggleSideBarButton);
         layout->addWidget(mToggleThumbnailBarButton);
@@ -329,7 +331,7 @@ struct ViewMainPagePrivate
         mThumbnailSplitter->setSizes(GwenviewConfig::thumbnailSplitterSizes());
 
         QVBoxLayout* layout = new QVBoxLayout(q);
-        layout->setMargin(0);
+        layout->setContentsMargins(0, 0, 0, 0);
         layout->addWidget(mThumbnailSplitter);
     }
 
@@ -449,13 +451,13 @@ ViewMainPage::ViewMainPage(QWidget* parent, SlideShow* slideShow, KActionCollect
     d->mSynchronizeAction = view->add<KToggleAction>("synchronize_views");
     d->mSynchronizeAction->setText(i18n("Synchronize"));
     actionCollection->setDefaultShortcut(d->mSynchronizeAction, Qt::CTRL + Qt::Key_Y);
-    connect(d->mSynchronizeAction, SIGNAL(toggled(bool)),
-            d->mSynchronizer, SLOT(setActive(bool)));
+    connect(d->mSynchronizeAction, &QAction::toggled,
+            d->mSynchronizer, &DocumentViewSynchronizer::setActive);
     // Ensure mSynchronizeAction and mSynchronizeCheckBox are in sync
-    connect(d->mSynchronizeAction, SIGNAL(toggled(bool)),
-            d->mSynchronizeCheckBox, SLOT(setChecked(bool)));
-    connect(d->mSynchronizeCheckBox, SIGNAL(toggled(bool)),
-            d->mSynchronizeAction, SLOT(setChecked(bool)));
+    connect(d->mSynchronizeAction, &QAction::toggled,
+            d->mSynchronizeCheckBox, &QAbstractButton::setChecked);
+    connect(d->mSynchronizeCheckBox, &QAbstractButton::toggled,
+            d->mSynchronizeAction, &QAction::setChecked);
 
     // Connections for the document count
     connect(d->mThumbnailBar, &ThumbnailBarView::rowsInsertedSignal,
