@@ -77,7 +77,7 @@ struct PrintOptionsPagePrivate : public Ui_PrintOptionsPage
         );
 
         QGridLayout* layout = new QGridLayout(mPositionFrame);
-        layout->setMargin(0);
+        layout->setContentsMargins(0, 0, 0, 0);
         layout->setSpacing(1);
         for (int row = 0; row < 3; ++row) {
             for (int col = 0; col < 3; ++col) {
@@ -128,8 +128,8 @@ PrintOptionsPage::PrintOptionsPage(const QSize& imageSize)
     connect(d->kcfg_PrintHeight, SIGNAL(valueChanged(double)),
             SLOT(adjustWidthToRatio()));
 
-    connect(d->kcfg_PrintKeepRatio, SIGNAL(toggled(bool)),
-            SLOT(adjustHeightToRatio()));
+    connect(d->kcfg_PrintKeepRatio, &QAbstractButton::toggled,
+            this, &PrintOptionsPage::adjustHeightToRatio);
 }
 
 PrintOptionsPage::~PrintOptionsPage()
