@@ -33,6 +33,10 @@ class QDragEnterEvent;
 class QDragMoveEvent;
 class QDropEvent;
 class QPixmap;
+class QGestureEvent;
+class QTapGesture;
+class QPinchGesture;
+class QGesture;
 
 namespace Gwenview
 {
@@ -48,7 +52,7 @@ class GWENVIEWLIB_EXPORT ThumbnailView : public QListView
 public:
     enum {
         MinThumbnailSize = 48,
-        MaxThumbnailSize = 256
+        MaxThumbnailSize = 512
     };
 
     enum ThumbnailScaleMode {
@@ -176,6 +180,8 @@ protected:
 
     void startDrag(Qt::DropActions) override;
 
+    void mousePressEvent(QMouseEvent*) override;
+
 protected Q_SLOTS:
     void rowsAboutToBeRemoved(const QModelIndex& parent, int start, int end) override;
     void rowsInserted(const QModelIndex& parent, int start, int end) override;
@@ -184,6 +190,10 @@ protected Q_SLOTS:
                      const QVector<int> &roles = QVector<int>()) override;
 
 private Q_SLOTS:
+    void startDragFromTouch(const QPoint& pos);
+    void tapGesture(const QPoint& pos);
+    void setZoomParameter();
+    void zoomGesture(qreal newZoom, const QPoint& pos);
     void showContextMenu();
     void emitIndexActivatedIfNoModifiers(const QModelIndex&);
     void setThumbnail(const KFileItem&, const QPixmap&, const QSize&, qulonglong fileSize);
